@@ -59,6 +59,9 @@ public class VmTemplateHandler implements BackendService {
     @Inject
     private StorageDomainDao storageDomainDao;
 
+    @Inject
+    private ImagesHandler imagesHandler;
+
     private ObjectIdentityChecker updateVmTemplate;
 
     /**
@@ -181,7 +184,7 @@ public class VmTemplateHandler implements BackendService {
                                 ONLY_ACTIVE);
             }
             if (vmtImages.size() > 0
-                    && !ImagesHandler.isImagesExists(vmtImages, vmtImages.get(0).getStoragePoolId())) {
+                    && !imagesHandler.isImagesExists(vmtImages, vmtImages.get(0).getStoragePoolId())) {
                 return new ValidationResult(EngineMessage.TEMPLATE_IMAGE_NOT_EXIST);
             }
         }
