@@ -17,12 +17,12 @@ import org.junit.Ignore;
 import org.junit.Test;
 import org.ovirt.engine.api.model.Tag;
 import org.ovirt.engine.api.restapi.resource.BaseBackendResource.WebFaultException;
+import org.ovirt.engine.core.common.action.ActionType;
 import org.ovirt.engine.core.common.action.TagsOperationParameters;
-import org.ovirt.engine.core.common.action.VdcActionType;
 import org.ovirt.engine.core.common.businessentities.Tags;
 import org.ovirt.engine.core.common.queries.NameQueryParameters;
-import org.ovirt.engine.core.common.queries.VdcQueryParametersBase;
-import org.ovirt.engine.core.common.queries.VdcQueryType;
+import org.ovirt.engine.core.common.queries.QueryParametersBase;
+import org.ovirt.engine.core.common.queries.QueryType;
 import org.ovirt.engine.core.compat.Guid;
 
 public class BackendTagsResourceTest
@@ -54,8 +54,8 @@ public class BackendTagsResourceTest
     @Test(expected = WebFaultException.class)
     public void testListLimitResultsBadFormat() throws Exception {
         UriInfo uriInfo = setUpUriExpectationsWithMax(true);
-        setUpEntityQueryExpectations(VdcQueryType.GetAllTags,
-                                     VdcQueryParametersBase.class,
+        setUpEntityQueryExpectations(QueryType.GetAllTags,
+                                     QueryParametersBase.class,
                                      new String[] { },
                                      new Object[] { },
                                      setUpTags(),
@@ -68,14 +68,14 @@ public class BackendTagsResourceTest
     @Test
     public void testAddTag() throws Exception {
         setUriInfo(setUpBasicUriExpectations());
-        setUpCreationExpectations(VdcActionType.AddTag,
+        setUpCreationExpectations(ActionType.AddTag,
                                   TagsOperationParameters.class,
                                   new String[] { "Tag.TagName", "Tag.ParentId" },
                                   new Object[] { NAMES[0], PARENT_GUID },
                                   true,
                                   true,
                                   null,
-                                  VdcQueryType.GetTagByTagName,
+                                  QueryType.GetTagByTagName,
                                   NameQueryParameters.class,
                                   new String[] { "Name" },
                                   new Object[] { NAMES[0] },
@@ -91,20 +91,20 @@ public class BackendTagsResourceTest
     public void testAddTagNamedParent() throws Exception {
         setUriInfo(setUpBasicUriExpectations());
 
-        setUpEntityQueryExpectations(VdcQueryType.GetTagByTagName,
+        setUpEntityQueryExpectations(QueryType.GetTagByTagName,
                                      NameQueryParameters.class,
                                      new String[] { "Name" },
                                      new Object[] { NAMES[PARENT_IDX] },
                                      getEntity(PARENT_IDX));
 
-        setUpCreationExpectations(VdcActionType.AddTag,
+        setUpCreationExpectations(ActionType.AddTag,
                                   TagsOperationParameters.class,
                                   new String[] { "Tag.TagName", "Tag.ParentId" },
                                   new Object[] { NAMES[0], PARENT_GUID },
                                   true,
                                   true,
                                   null,
-                                  VdcQueryType.GetTagByTagName,
+                                  QueryType.GetTagByTagName,
                                   NameQueryParameters.class,
                                   new String[] { "Name" },
                                   new Object[] { NAMES[0] },
@@ -127,14 +127,14 @@ public class BackendTagsResourceTest
         Tags entity = getEntity(0);
         entity.setParentId(Guid.Empty);
 
-        setUpCreationExpectations(VdcActionType.AddTag,
+        setUpCreationExpectations(ActionType.AddTag,
                                   TagsOperationParameters.class,
                                   new String[] { "Tag.TagName", "Tag.ParentId" },
                                   new Object[] { NAMES[0], Guid.Empty },
                                   true,
                                   true,
                                   null,
-                                  VdcQueryType.GetTagByTagName,
+                                  QueryType.GetTagByTagName,
                                   NameQueryParameters.class,
                                   new String[] { "Name" },
                                   new Object[] { NAMES[0] },
@@ -170,7 +170,7 @@ public class BackendTagsResourceTest
     }
 
     private void doTestBadAddTag(boolean valid, boolean success, String detail) throws Exception {
-        setUriInfo(setUpActionExpectations(VdcActionType.AddTag,
+        setUriInfo(setUpActionExpectations(ActionType.AddTag,
                                            TagsOperationParameters.class,
                                            new String[] { "Tag.TagName", "Tag.ParentId" },
                                            new Object[] { NAMES[0], PARENT_GUID },
@@ -188,16 +188,16 @@ public class BackendTagsResourceTest
     protected void setUpQueryExpectations(String query, Object failure) throws Exception {
         assertEquals("", query);
 
-        setUpEntityQueryExpectations(VdcQueryType.GetAllTags,
-                                     VdcQueryParametersBase.class,
+        setUpEntityQueryExpectations(QueryType.GetAllTags,
+                                     QueryParametersBase.class,
                                      new String[] { },
                                      new Object[] { },
                                      setUpTags(),
                                      failure);
 
         if (failure == null) {
-            setUpEntityQueryExpectations(VdcQueryType.GetRootTag,
-                                         VdcQueryParametersBase.class,
+            setUpEntityQueryExpectations(QueryType.GetRootTag,
+                                         QueryParametersBase.class,
                                          new String[] { },
                                          new Object[] { },
                                          setUpRootTag());
